@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: chr.h,v 1.126 2009/08/28 05:40:11 bowkenken Exp $
+* $Id: chr.h,v 1.128 2010/05/13 17:31:58 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CHR_H
@@ -610,6 +610,23 @@ typedef struct {
 	dist_t	dist, dflt_dist_mnstr;
 } trgt_t;
 
+/***************************************************************
+* С
+***************************************************************/
+
+typedef enum {
+	POSITION_KIND_NULL,
+
+	/*  */
+	POSITION_KIND_FORWARD,
+	/*  */
+	POSITION_KIND_HALFBACK,
+	/*  */
+	POSITION_KIND_BACK,
+
+	POSITION_KIND_MAX_N,
+} position_kind_t;
+
 /***************************************************************
 * ١ȿ
 ***************************************************************/
@@ -800,8 +817,10 @@ typedef struct chr_t {
 	/* ԡɻ ID */
 	long	id1, id2;
 
-	/* PCλ¤ӽ */
+	/* С¤ӽ */
 	long	mbr_n, ls_mbr_n;
+	/* С */
+	position_kind_t	position_kind;
 
 	/*  */
 	chr_face_t	face;
