@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: crsr-ptn.h,v 1.9 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: crsr-ptn.h,v 1.11 2010/07/30 23:01:20 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	CRSR_PTN_H
@@ -59,7 +59,15 @@ crsr_ptn_t	crsr_ptn_dflt[] = {
 		0, 0,
 		'@',
 		{
-			"@@@@<-",
+			"@@@@<=",
+		},
+	},
+	{
+		+0, +0,
+		0, 0,
+		'@',
+		{
+			"@@",
 		},
 	},
 };
