@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: draw.h,v 1.73 2010/05/31 06:08:20 bowkenken Exp $
+* $Id: draw.h,v 1.77 2010/08/31 22:04:40 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	DRAW_H
@@ -94,8 +94,8 @@
 		(WIN_MENU_DRAW_MAX_X - WIN_MENU_DRAW_MIN_X + 1)
 #define	WIN_MENU_DRAW_HEIGHT	\
 		(WIN_MENU_DRAW_MAX_Y - WIN_MENU_DRAW_MIN_Y + 1)
-#define	WIN_MENU_DRAW_MAX_X	SCREEN_MAX_X
-#define	WIN_MENU_DRAW_MAX_Y	(WIN_MSG_DRAW_MIN_Y - 1)
+#define	WIN_MENU_DRAW_MAX_X	(get_screen_col() - 1)
+#define	WIN_MENU_DRAW_MAX_Y	(get_map_row() - 1)
 
 #define	WIN_MSG_DRAW_MIN_X	0
 #define	WIN_MSG_DRAW_MIN_Y	(WIN_MAP_DRAW_MAX_Y + 2)
@@ -123,6 +123,17 @@
 #define	WIN_STAT_DRAW_MAX_Y	(WIN_STAT_DRAW_MIN_Y \
 		+ ((MBR_MAX_N) * WIN_STAT_DRAW_HEIGHT - 1) - 1)
 
+/***************************************************************
+* ơɽΥ⡼ڤ괹
+***************************************************************/
+
+typedef enum {
+	STAT_MODE_MBR,
+	STAT_MODE_PET,
+
+	STAT_MODE_MAX_N,
+} stat_mode_t;
+
 /***************************************************************
 * åɽؿΥե饰
 ***************************************************************/
@@ -228,6 +239,39 @@ typedef unsigned long	flg_vfx_mnstr_t;
 #define	VFX_WAIT_MIN_N	1
 #define	VFX_WAIT_MAX_N	200
 
+/***************************************************************
+* GUI Υӥ奢롦ե
+***************************************************************/
+
+/* եȤμ */
+typedef enum {
+	GUI_VFX_KIND_NULL,
+
+	GUI_VFX_KIND_BASH,
+	GUI_VFX_KIND_ARW,
+	GUI_VFX_KIND_THROW_ITEM,
+	GUI_VFX_KIND_SPELL,
+	GUI_VFX_KIND_BLAST,
+	GUI_VFX_KIND_NINJA,
+
+	GUI_VFX_KIND_MAX_N,
+} gui_vfx_kind_t;
+
+/* GUI Υӥ奢롦եȤΥǡ */
+typedef struct gui_vfx_t {
+	bool_t	flg_use;
+
+	rate_t	anim_rate;
+	bool_t	flg_crtcl;
+	gui_vfx_kind_t	kind;
+	long	dir_n;
+	char	mjr;
+	char	mnr;
+	resi_kind_t	resi_kind;
+	blast_kind_t	blast_kind;
+	spell_kind_t	spell_kind;
+} gui_vfx_t;
+
 /***************************************************************
 * ޥɡ
 ***************************************************************/
