@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile-tab.h,v 1.40 2010/06/03 12:45:57 bowkenken Exp $
+* $Id: gfile-tab.h,v 1.41 2010/08/05 00:08:46 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_TAB_H
@@ -2079,4 +2079,24 @@ request_kind_t	g_request_trans_tab[] = {
 	/* ɲ */
 };
 
+/***************************************************************
+* ֡ǡ򥻡֡ɤ
+* ߴݻ뤿Ѵơ֥롣
+* 
+*  Ф˽֤ѹʤͤˡ 
+* 
+* ɬơ֥ɲäơ
+* ֡եΥСѤ롣
+* 
+*  STAY_INN_KIND_LONG ǡ롣
+***************************************************************/
+
+stay_inn_kind_t	g_stay_inn_kind_trans_tab[] = {
+	STAY_INN_KIND_LONG,
+	STAY_INN_KIND_SHORT,
+	STAY_INN_KIND_MEWS,
+
+	/* ɲ */
+};
+
 #endif	/* GFILE_TAB_H */
