@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.143 2010/05/29 14:37:00 bowkenken Exp $
+* $Id: gmain.c,v 1.151 2010/09/01 08:38:36 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -75,27 +75,24 @@ check_memory_def( check_memory_gmain_c_pre_tbuf )
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"GCUA:N:P:T:D:S:l:k:e:s:p:m:cd:Vvh"
+#define	STR_OPT	"GCUM:A:N:P:l:es:p:m:cdVvh"
 
 #ifdef	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
 	{ "gui",            no_argument,       NULL, 'G' },
 	{ "cui",            no_argument,       NULL, 'C' },
 	{ "gui-and-cui",    no_argument,       NULL, 'U' },
+	{ "cui-mouse",      required_argument, NULL, 'M' },
 	{ "audio-buf-size", required_argument, NULL, 'A' },
 	{ "gnome",          required_argument, NULL, 'N' },
 	{ "set-win-pos",    required_argument, NULL, 'P' },
-	{ "text-mode",      required_argument, NULL, 'T' },
-	{ "sel-graph-dir",  required_argument, NULL, 'D' },
-	{ "map-scale",      required_argument, NULL, 'S' },
 	{ "language",       required_argument, NULL, 'l' },
-	{ "clear-key-buf",  required_argument, NULL, 'k' },
-	{ "echo-key",       required_argument, NULL, 'e' },
+	{ "echo-key",       no_argument,       NULL, 'e' },
 	{ "use-curses",     required_argument, NULL, 's' },
 	{ "use-keypad",     required_argument, NULL, 'p' },
 	{ "check-memory",   required_argument, NULL, 'm' },
 	{ "measure-clock",  no_argument,       NULL, 'c' },
-	{ "debug",          required_argument, NULL, 'd' },
+	{ "debug",          no_argument,       NULL, 'd' },
 	{ "version",        no_argument,       NULL, 'V' },
 	{ "help",           no_argument,       NULL, 'h' },
 	{ 0, 0, 0, 0 }
@@ -113,27 +110,16 @@ char	str_usage[] = {
 	"  -G, --gui                 set GUI mode\n"
 	"  -C, --cui                 set CUI mode\n"
 	"  -U, --gui-and-cui         set GUI and CUI mode\n"
+	"  -M, --cui-mouse=FLAG      use CUI mouse\n"
+	"                              ON, OFF or SWAP\n"
 	"  -A, --audio-buf-size=SIZE set audio buffer size\n"
-	"  -N, --gnome               window manager is GNOME\n"
+	"  -N, --gnome=FLAG          window manager is GNOME\n"
 	"                              ON or OFF\n"
-	"  -P, --set-win-pos         set window position\n"
+	"  -P, --set-win-pos=FLAG    set window position\n"
 	"                              ON or OFF\n"
-#if	defined( DEBUG ) || !defined( NDEBUG )
-	"  -T, --text-mode=POINT     set TEXT mode:\n"
-	"                              point of font, ON or OFF\n"
-	"  -D, --sel-graph-dir=DIR   select graphic directory:\n"
-	"                              graphic directory\n"
-	"  -S, --map-scale=N         set scale of map character:\n"
-	"                              scale(%%)\n"
-#endif
 	"  -l, --language=LANGUAGE   set language:\n"
 	"                              language\n"
-#if	defined( DEBUG ) || !defined( NDEBUG )
-	"  -k, --clear-key-buf=FLAG  clear key buffer:\n"
-	"                              ON or OFF\n"
-#endif
-	"  -e, --echo-key=FLAG       echo key:\n"
-	"                              ON or OFF\n"
+	"  -e, --echo-key            echo key\n"
 	"  -s, --use-curses=FLAG     use curses library:\n"
 	"                              ON or OFF\n"
 	"  -p, --use-keypad=FLAG     use cursor key (call keypad):\n"
@@ -142,14 +128,19 @@ char	str_usage[] = {
 	"                              ON or OFF\n"
 	"  -c, --measure-clock       measure frame rate\n"
 #if	defined( DEBUG ) || !defined( NDEBUG )
-	"  -d, --debug=FLAG          set debug mode:\n"
-	"                              ON or OFF\n"
+	"  -d, --debug               debugging mode\n"
 #endif
 	"  -V, -v, --version         display version and exit\n"
 	"  -h, --help                display this help and exit\n"
 };
 check_memory_def( check_memory_gmain_c_str_usage )
 
+typedef enum {
+	OPT_ARG_KIND_FALSE,
+	OPT_ARG_KIND_TRUE,
+	OPT_ARG_KIND_SWAP,
+} opt_arg_kind_t;
+
 /***************************************************************
 * Τν
 ***************************************************************/
@@ -175,6 +166,7 @@ void	init_game( void )
 	init_msg();
 	init_draw();
 	init_replay();
+	init_playing_report();
 
 	init_game_file();
 
@@ -182,6 +174,8 @@ void	init_game( void )
 	init_var_main_menu();
 	init_var_misc_menu();
 
+	init_crsr_ptn();
+
 	if( !load_game_conf() )
 		g_flg_measure_clk_tck = TRUE;
 	overwrite_arg();
@@ -267,6 +261,7 @@ void	reset_static( void )
 
 #if	defined( D_GTK )
 #elif	defined( D_WS )
+#elif	defined( D_IPHONE )
 #elif	defined( D_MFC )
 #elif	defined( D_DOS )
 	reset_static_main_dos();
@@ -289,6 +284,8 @@ void	reset_static_game_main( void )
 
 void	game_main( void )
 {
+	call_alloc_autorelease_pool();
+
 	chk_scroll( TRUE );
 	redraw_all();
 	scroll_center_appear_party();
@@ -311,8 +308,12 @@ void	game_main( void )
 			party_exit_bar();
 	}
 
+	call_release_autorelease_pool();
+
 	while( 1 ){
+		call_alloc_autorelease_pool();
 		chk_key( g_flg_clr_key_buf, TRUE );
+		call_release_autorelease_pool();
 	}
 }
 
@@ -384,6 +385,8 @@ void	init_arg( void )
 
 	g_flg_cui = TRUE;
 	g_flg_gui = FALSE;
+	g_flg_cui_mouse = FALSE;
+	g_flg_cui_mouse_swap_btn = FALSE;
 
 	g_audio_buf_siz_arg_overwrite = FALSE;
 	g_audio_buf_siz_arg = 1024;
@@ -475,6 +478,19 @@ void	chk_arg( int argc, char **argv )
 			g_flg_cui = TRUE;
 			g_flg_gui = TRUE;
 			break;
+		case 'M':
+			chk_opt_flg( optarg, &g_flg_cui_mouse, TRUE );
+			if( g_flg_cui_mouse == OPT_ARG_KIND_SWAP ){
+				g_flg_cui_mouse = TRUE;
+				g_flg_cui_mouse_swap_btn = TRUE;
+			} else if( g_flg_cui_mouse ){
+				g_flg_cui_mouse = TRUE;
+				g_flg_cui_mouse_swap_btn = FALSE;
+			} else {
+				g_flg_cui_mouse = FALSE;
+				g_flg_cui_mouse_swap_btn = FALSE;
+			}
+			break;
 		case 'A':
 			g_audio_buf_siz_arg_overwrite = TRUE;
 			chk_opt_num( optarg, &g_audio_buf_siz_arg, TRUE );
@@ -487,22 +503,6 @@ void	chk_arg( int argc, char **argv )
 			g_flg_win_pos_arg_overwrite = TRUE;
 			chk_opt_flg( optarg, &g_flg_set_win_pos_arg, TRUE );
 			break;
-		case 'T':
-			if( chk_opt_flg( optarg, &g_flg_text_mode,
-					FALSE ) ){
-				g_text_mode_point = 0;
-			} else {
-				g_flg_text_mode = TRUE;
-				chk_opt_num( optarg, &g_text_mode_point,
-						TRUE );
-			}
-			break;
-		case 'D':
-			call_set_str_dir_sel_graph( optarg );
-			break;
-		case 'S':
-			chk_opt_num( optarg, &g_graph_scale_rate, TRUE );
-			break;
 		case 'l':
 			if( g_language != NULL )
 				free_mem( g_language );
@@ -513,12 +513,8 @@ void	chk_arg( int argc, char **argv )
 
 			str_nz_cpy( g_language, optarg, len );
 			break;
-		case 'k':
-			g_flg_clr_key_buf_arg_overwrite = TRUE;
-			chk_opt_flg( optarg, &g_flg_clr_key_buf_arg, TRUE );
-			break;
 		case 'e':
-			chk_opt_flg( optarg, &g_flg_echo_key, TRUE );
+			g_flg_echo_key = TRUE;
 			break;
 		case 's':
 			chk_opt_flg( optarg, &g_flg_use_curs, TRUE );
@@ -533,7 +529,7 @@ void	chk_arg( int argc, char **argv )
 			g_flg_measure_clk_tck = TRUE;
 			break;
 		case 'd':
-			chk_opt_flg( optarg, &g_flg_debug, TRUE );
+			g_flg_debug = TRUE;
 			break;
 		case 'V':
 		case 'v':
@@ -559,6 +555,9 @@ void	chk_arg( int argc, char **argv )
 		usage( stderr );
 		gexit( EXIT_FAILURE );
 	}
+
+	if( g_flg_gui || !g_flg_cui )
+		g_flg_cui_mouse = FALSE;
 }
 
 /***************************************************************
@@ -654,6 +653,12 @@ bool_t	chk_opt_flg(
 	if( strcmp( str, "0" ) == 0 )
 		return TRUE;
 
+	*flg = OPT_ARG_KIND_SWAP;
+	if( strcmp( str, "SWAP" ) == 0 )
+		return TRUE;
+
+	*flg = FALSE;
+
 	if( flg_err_exit ){
 		usage( stderr );
 		gexit( EXIT_FAILURE );
@@ -713,6 +718,8 @@ void	exit_game( long code )
 
 void	close_game( long code )
 {
+	call_close_game_gui();
+
 	close_item();
 
 	if( !g_flg_use_curs )
@@ -1297,6 +1304,7 @@ void	check_memory_all( void )
 	check_memory_key_item_c();
 	check_memory_last_boss_c();
 #if	defined( D_GTK )
+#elif	defined( D_IPHONE )
 #elif	defined( D_MFC )
 #elif	defined( D_DOS )
 	check_memory_main_dos_c();
