@@ -8,6 +8,7 @@ void	init_var_misc_menu( void );
 void	reset_static_misc_menu( void );
 void	init_misc_menu( void );
 char	*cb_menu_misc( menu_t **pp, menu_t **dflt );
+char	*cb_menu_info( menu_t **pp, menu_t **dflt );
 char	*cb_menu_continue_exec( menu_t **pp, menu_t **dflt );
 bool_t	chk_continue_exec_mode( long *c, bool_t *p_flg_clr_key_buf );
 bool_t	get_continue_exec_mode( void );
@@ -31,7 +32,8 @@ void	show_map_hint_obj( long x, long y );
 const char	*get_str_map_hint_chr( long x, long y );
 const char	*get_str_map_hint_obj( long x, long y );
 char	*cb_menu_chr_data( menu_t **pp, menu_t **dflt );
-char	*menu_sel_mbr_data( void );
+char	*menu_sel_mbr_data( long sel_mbr_n );
+char	*menu_sel_pet_data( long sel_pet_n );
 long	menu_show_mbr_data( mbr_t *mbr, long *page_n, data_n_t *data_n );
 long	menu_edit_mbr_data( mbr_t *mbr, long *page_n, data_n_t *data_n );
 long	menu_mbr_data(
@@ -51,7 +53,8 @@ void	exec_menu_edit_mbr_data(
 );
 bool_t	exec_menu_ask_edit_mbr_data( mbr_t *org_p, mbr_t *mbr_p );
 void	sel_mbr_graph_file( mbr_t *mbr );
-char	*menu_sel_mnstr_data( void );
+char	*menu_sel_mnstr_data( mnstr_t *mnstr );
+char	*cb_menu_switch_stat_mode( menu_t **pp, menu_t **dflt );
 char	*cb_menu_gold( menu_t **pp, menu_t **dflt );
 char	*cb_menu_collect_gold( menu_t **pp, menu_t **dflt );
 char	*cb_menu_divide_gold( menu_t **pp, menu_t **dflt );
@@ -106,11 +109,14 @@ bool_t	next_pos_door( long d );
 bool_t	next_pos_square( long d );
 bool_t	next_pos_all( long d );
 bool_t	prev_pos( void );
+char	*cb_menu_msg( menu_t **pp, menu_t **dflt );
 char	*cb_menu_back_log( menu_t **pp, menu_t **dflt );
 char	*exec_back_log( void );
 char	*cb_menu_ls_msg( menu_t **pp, menu_t **dflt );
+char	*cb_menu_scroll_msg( menu_t **pp, menu_t **dflt );
 char	*cb_menu_ls_key_item( menu_t **pp, menu_t **dflt );
 char	*cb_menu_ls_mnstr( menu_t **pp, menu_t **dflt );
+char	*cb_menu_set_dflt_cnf( menu_t **pp, menu_t **dflt );
 char	*cb_menu_cnf( menu_t **pp, menu_t **dflt );
 char	*cb_menu_mbr_flg( menu_t **pp, menu_t **dflt );
 char	*cb_menu_mbr_flg_init( menu_t **pp, menu_t **dflt );
@@ -121,6 +127,7 @@ char	*cb_menu_auto_reload( menu_t **pp, menu_t **dflt );
 char	*cb_menu_actual_fighting( menu_t **pp, menu_t **dflt );
 char	*cb_menu_space_select( menu_t **pp, menu_t **dflt );
 char	*cb_menu_reset_file_config( menu_t **pp, menu_t **dflt );
+char	*cb_menu_reset_file_crsr_ptn( menu_t **pp, menu_t **dflt );
 char	*cb_menu_reset_file_town_ptn( menu_t **pp, menu_t **dflt );
 char	*cb_menu_lang( menu_t **pp, menu_t **dflt );
 char	*cb_menu_lang_ls( menu_t **pp, menu_t **dflt );
@@ -136,6 +143,9 @@ void	set_scroll_smooth( void );
 void	set_scroll_center( void );
 char	*cb_menu_redraw_every_turn( menu_t **pp, menu_t **dflt );
 char	*cb_menu_mul_msg_line( menu_t **pp, menu_t **dflt );
+char	*cb_menu_stat_bar_init( menu_t **pp, menu_t **dflt );
+char	*cb_menu_stat_bar_hint_chr( menu_t **pp, menu_t **dflt );
+char	*cb_menu_stat_bar_hint_obj( menu_t **pp, menu_t **dflt );
 char	*cb_menu_screen_size_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_screen_size_auto( menu_t **pp, menu_t **dflt );
 char	*cb_menu_screen_size_col( menu_t **pp, menu_t **dflt );
@@ -159,8 +169,10 @@ void	set_bg_color( curs_attr_t *attr, int color );
 char	*cb_menu_attr_init( menu_t **pp, menu_t **dflt );
 char	*cb_menu_attr( menu_t **pp, menu_t **dflt );
 void	set_color_attr( curs_attr_t *attr, bool_t flg_on, chtype_t ch );
+void	rev_color_attr( curs_attr_t *attr, chtype_t ch );
 char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt );
-char	*cb_menu_crsr_ptn_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_main_crsr_ptn_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_sub_crsr_ptn_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_demo( menu_t **pp, menu_t **dflt );
 char	*cb_menu_skip_cut_in( menu_t **pp, menu_t **dflt );
 char	*cb_menu_star_cui( menu_t **pp, menu_t **dflt );
@@ -180,8 +192,11 @@ char	*cb_menu_func_edit( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_set_reg_macro( menu_t **pp, menu_t **dflt );
 char	*cb_menu_func_unset( menu_t **pp, menu_t **dflt );
 long	get_func_draw_n( long n );
-char	*cb_menu_gui( menu_t **pp, menu_t **dflt );
-char	*cb_menu_move_crsr_dflt( menu_t **pp, menu_t **dflt );
+char	*cb_menu_mouse_init( menu_t **pp, menu_t **dflt );
+char	*cb_menu_mouse_move_crsr_dflt( menu_t **pp, menu_t **dflt );
+long	get_cui_mouse_double_click_msec( void );
+void	set_cui_mouse_double_click_msec( long msec );
+char	*cb_menu_mouse_double_click( menu_t **pp, menu_t **dflt );
 char	*cb_menu_audio( menu_t **pp, menu_t **dflt );
 char	*cb_menu_music_volume( menu_t **pp, menu_t **dflt );
 char	*cb_menu_sound_volume( menu_t **pp, menu_t **dflt );
@@ -221,14 +236,16 @@ char	*arrange_menu_user_1( long n, long d );
 char	*cb_menu_user_arrange_top_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_arrange_bottom_sel( menu_t **pp, menu_t **dflt );
 char	*cb_menu_user_remove_sel( menu_t **pp, menu_t **dflt );
+char	*cb_menu_set_dflt_system( menu_t **pp, menu_t **dflt );
 char	*cb_menu_system( menu_t **pp, menu_t **dflt );
-char	*cb_menu_command( menu_t **pp, menu_t **dflt );
 char	*cb_menu_replay_load( menu_t **pp, menu_t **dflt );
 char	*cb_menu_replay_save( menu_t **pp, menu_t **dflt );
 char	*cb_menu_replay_debug( menu_t **pp, menu_t **dflt );
 char	*cb_menu_replay_bug_repo( menu_t **pp, menu_t **dflt );
 long	menu_replay_sel_load( void );
 char	*cb_menu_replay_sel_load( menu_t **pp, menu_t **dflt );
+char	*cb_menu_command( menu_t **pp, menu_t **dflt );
+char	*cb_menu_set_dflt_wizard( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_teleport_party( menu_t **pp, menu_t **dflt );
 char	*cb_menu_wizard_recall( menu_t **pp, menu_t **dflt );
@@ -246,6 +263,9 @@ char	*cb_menu_shell( menu_t **pp, menu_t **dflt );
 char	*cb_menu_about_game( menu_t **pp, menu_t **dflt );
 char	*cb_menu_exit( menu_t **pp, menu_t **dflt );
 void	set_menu_dflt_misc( menu_t *p );
+void	set_menu_dflt_cnf( menu_t *p );
+void	set_menu_dflt_system( menu_t *p );
+void	set_menu_dflt_wizard( menu_t *p );
 bool_t	*get_ls_flg_srch( void );
 menu_t	*get_ls_menu_move_crsr( void );
 flg_scroll_t	get_flg_scroll( void );
