@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-unix.c,v 1.23 2009/01/04 00:24:52 bowkenken Exp $
+* $Id: main-unix.c,v 1.25 2010/01/07 07:12:21 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -71,3 +71,11 @@ void	gexit( long code )
 {
 	exit( code );
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_main_unix_c( void )
+{
+}
