@@ -5,6 +5,7 @@ extern "C" {
 #endif
 
 void	init_trap( void );
+void	reset_static_trap( void );
 void	reset_trap( void );
 trap_t	*make_trap( long x, long y, long dun_lev );
 trap_t	*make_trap_std( trap_kind_t kind, long x, long y, long dun_lev );
@@ -32,8 +33,21 @@ void	free_trap( trap_t *p );
 trap_t	*get_trap_free_next( void );
 trap_t	*get_dun_trap_asgn( void );
 trap_t	*get_trap( long x, long y );
+trap_t	*get_trap_nearest( chr_t *chr, act_kind_t act_kind );
+trap_t	*get_trap_near( chr_t *chr, act_kind_t act_kind );
+trap_t	*get_trap_disperse( chr_t *chr, act_kind_t act_kind );
+trap_t	*get_trap_randm( chr_t *chr, act_kind_t act_kind );
+trap_t	*get_trap_identified( chr_t *chr, act_kind_t act_kind );
+trap_t	*get_trap_un_identified( chr_t *chr, act_kind_t act_kind );
+trap_t	*get_trap_identified_sub(
+	chr_t *chr, act_kind_t act_kind,
+	bool_t flg_identified
+);
+bool_t	chk_get_trap( chr_t *chr, act_kind_t act_kind, trap_t *p );
+bool_t	chk_mark_trap( trap_t *p, act_kind_t act_kind );
 trap_tab_t	*get_trap_tab( trap_kind_t kind );
 long	get_trap_tab_n( trap_kind_t kind );
+void	check_memory_trap_c( void );
 
 #ifdef __cplusplus
 }
